@@ -23,6 +23,7 @@ SCRIPTS: Dict[str, str] = {
     'magic-arrays': from_file('magic-arrays.js'),
     'media_codecs': from_file('media.codecs.js'),
     'navigator_hardware_concurrency': from_file('navigator.hardwareConcurrency.js'),
+    'navigator_device_memory': from_file('navigator.deviceMemory.js'),
     'navigator_languages': from_file('navigator.languages.js'),
     'navigator_permissions': from_file('navigator.permissions.js'),
     'navigator_platform': from_file('navigator.platform.js'),
@@ -77,6 +78,7 @@ class StealthConfig:
     navigator_languages: bool = True
     navigator_user_agent: bool = True
     navigator_permissions: bool = True
+    navigator_device_memory: bool = True
     navigator_hardware_concurrency: bool = True
 
     # options
@@ -86,6 +88,7 @@ class StealthConfig:
     nav_vendor: str = 'Apple Computer, Inc.'
     nav_platform: str = 'iPhone'
     nav_user_agent: str = None
+    device_memory: int = 0
     hardware_concurrency: int = -1
 
     @property
@@ -97,13 +100,14 @@ class StealthConfig:
             'navigator_platform': self.nav_platform,
             'navigator_user_agent': self.nav_user_agent,
             'max_touch_points': self.max_touch_points,
+            'navigator_device_memory': self.device_memory,
             'hardwareConcurrency': self.hardware_concurrency,
         })
         # defined options constant
         yield f'const opts = {opts}'
         # init utils and magic-arrays helper
         yield SCRIPTS['utils']
-        # yield SCRIPTS['magic-arrays']
+        yield SCRIPTS['magic-arrays']
 
         if self.hairline:
             yield SCRIPTS['hairline']
@@ -139,6 +143,8 @@ class StealthConfig:
             yield SCRIPTS['navigator_languages']
         if self.navigator_user_agent:
             yield SCRIPTS['navigator_user_agent']
+        if self.navigator_device_memory:
+            yield SCRIPTS['navigator_device_memory']
         if self.navigator_hardware_concurrency:
             yield SCRIPTS['navigator_hardware_concurrency']
         yield SCRIPTS['user_agent_override']
